@@ -4,10 +4,9 @@
 
 from __future__ import annotations
 
-import sys
 import tokenize
 from collections import defaultdict
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 from pylint import exceptions, interfaces
 from pylint.constants import (
@@ -19,7 +18,7 @@ from pylint.constants import (
 )
 from pylint.interfaces import HIGH
 from pylint.message import MessageDefinition
-from pylint.typing import ManagedMessage
+from pylint.typing import ManagedMessage, MessageDefinitionTuple
 from pylint.utils.pragma_parser import (
     OPTION_PO,
     InvalidPragmaError,
@@ -27,12 +26,6 @@ from pylint.utils.pragma_parser import (
     parse_pragma,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 if TYPE_CHECKING:
     from pylint.lint.pylinter import PyLinter
 
@@ -44,6 +37,11 @@ class _MessageStateHandler:
 
     def __init__(self, linter: PyLinter) -> None:
         self.linter = linter
+        self.default_enabled_messages: dict[str, MessageDefinitionTuple] = {
+            k: v
+            for k, v in self.linter.msgs.items()
+            if len(v) == 3 or v[3].get("default_enabled", True)
+        }
         self._msgs_state: dict[str, bool] = {}
         self._options_methods = {
             "enable": self.enable,
@@ -55,9 +53,8 @@ class _MessageStateHandler:
             "enable-msg": self._options_methods["enable"],
         }
         self._pragma_lineno: dict[str, int] = {}
-        # TODO: 3.0: Update key type to str when current_name is always str
         self._stashed_messages: defaultdict[
-            tuple[str | None, str], list[tuple[str | None, str]]
+            tuple[str, str], list[tuple[str | None, str]]
         ] = defaultdict(list)
         """Some messages in the options (for --enable and --disable) are encountered
         too early to warn about them.
@@ -92,6 +89,14 @@ class _MessageStateHandler:
                 message_definitions.extend(
                     self._get_messages_to_set(_msgid, enable, ignore_unknown)
                 )
+            if not enable:
+                # "all" should not disable pylint's own warnings
+                message_definitions = list(
+                    filter(
+                        lambda m: m.msgid not in self.default_enabled_messages,
+                        message_definitions,
+                    )
+                )
             return message_definitions
 
         # msgid is a category?
@@ -313,12 +318,14 @@ class _MessageStateHandler:
         line: int | None = None,
         confidence: interfaces.Confidence | None = None,
     ) -> bool:
-        """Return whether this message is enabled for the current file, line and
-        confidence level.
+        """Is this message enabled for the current file ?
 
-        This function can't be cached right now as the line is the line of
-        the currently analysed file (self.file_state), if it changes, then the
-        result for the same msg_descr/line might need to change.
+        Optionally, is it enabled for this line and confidence level ?
+
+        The current file is implicit and mandatory. As a result this function
+        can't be cached right now as the line is the line of the currently
+        analysed file (self.file_state), if it changes, then the result for
+        the same msg_descr/line might need to change.
 
         :param msg_descr: Either the msgid or the symbol for a MessageDefinition
         :param line: The line of the currently analysed file
